{% extends "balafon/bs_base.html" %}
{% load i18n %}

{% block document_title %}{% trans "See my groups" %}{% endblock %}
{% block document_content %}
{% include "Crm/_section_my_groups.html" %}
{% endblock %}
